import { MDCTabBar } from '@material/tab-bar';
import { h, Host } from "@stencil/core";
export class Tabs {
    constructor() {
        /** Index de la tab sélectionner */
        this.activeTab = 0;
        /** Couleur de fond de la tabs */
        this.color = 'background';
        /** type d'indicateur */
        this.indicatorType = 'underline';
        /** Tabs de taille minimum */
        this.shrinkTabs = false;
    }
    watchActiveTab(newVal) {
        if (this.mdcTabs) {
            this.mdcTabs.activateTab(newVal);
        }
    }
    componentWillLoad() {
        const tabElements = Array.from(this.host.querySelectorAll('materials-tab'));
        this.tabElements = [...tabElements];
        this.tabObserver();
    }
    componentDidLoad() {
        this.initTabBar();
        this.mdcTabs.activateTab(this.activeTab);
    }
    componentDidUpdate() {
        this.mdcTabs.initialize();
    }
    tabObserver() {
        new MutationObserver((mutations, _observer) => {
            for (const mutation of mutations) {
                if (mutation.type === "childList") {
                    const tabElements = Array.from(this.host.querySelectorAll('materials-tab'));
                    this.tabElements = [...tabElements];
                }
            }
        }).observe(this.host, { childList: true });
    }
    initTabBar() {
        this.mdcTabs = MDCTabBar.attachTo(this.navBar);
        this.mdcTabs.listen('MDCTabBar:activated', (tab) => {
            const { index } = tab.detail;
            this.activeTab = index;
            this.tabChange.emit(index);
        });
    }
    getHostClasses() {
        const { color } = this;
        return {
            'materials-tab-background': color === 'background',
            'materials-tab-primary': color === 'primary',
            'materials-tab-secondary': color === 'secondary',
            'materials-tab-surface': color === 'surface'
        };
    }
    getTabClasses(tab) {
        return {
            'mdc-tab': true,
            'mdc-tab--active': tab.active,
            'mdc-tab--min-width': this.shrinkTabs
        };
    }
    getIndicatorClasses() {
        return {
            'mdc-tab-indicator__content': true,
            'mdc-tab-indicator__content--icon': this.indicatorType === 'icon',
            'mdc-tab-indicator__content--underline': this.indicatorType === 'underline',
            'material-icons': this.indicatorType === 'icon'
        };
    }
    render() {
        return (h(Host, { class: this.getHostClasses() },
            h("nav", { ref: e => this.navBar = e, class: "mdc-tab-bar", role: "tablist" },
                h("div", { class: "mdc-tab-scroller" },
                    h("div", { class: "mdc-tab-scroller__scroll-area" },
                        h("div", { class: "mdc-tab-scroller__scroll-content" }, this.tabElements.map(tab => {
                            const badge = tab.querySelector('materials-badge');
                            const label = tab.getAttribute('label') || tab.label;
                            return (h("button", { class: this.getTabClasses(tab), role: "tab", "aria-selected": "true", tabindex: tab.active ? '0' : '-1' },
                                h("span", { class: "mdc-tab__content" },
                                    tab.icon && h("span", { class: "mdc-tab__icon material-icons", "aria-hidden": "true" }, tab.icon),
                                    h("span", { class: "mdc-tab__text-label" }, label ? label : h("slot", null))),
                                h("span", { class: { 'mdc-tab-indicator': true, 'mdc-tab-indicator--active': tab.active } },
                                    h("span", { class: this.getIndicatorClasses() }, this.indicatorType === 'icon' && 'star')),
                                h("span", { class: "mdc-tab__ripple" }),
                                badge && h("materials-badge", null, badge.innerText)));
                        })))))));
    }
    static get is() { return "materials-tabs"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["tabs.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["tabs.css"]
    }; }
    static get properties() { return {
        "activeTab": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Index de la tab s\u00E9lectionner"
            },
            "attribute": "active-tab",
            "reflect": false,
            "defaultValue": "0"
        },
        "color": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "'background' | 'primary' | 'secondary' | 'surface'",
                "resolved": "\"background\" | \"primary\" | \"secondary\" | \"surface\"",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Couleur de fond de la tabs"
            },
            "attribute": "color",
            "reflect": false,
            "defaultValue": "'background'"
        },
        "indicatorType": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "'underline' | 'icon'",
                "resolved": "\"icon\" | \"underline\"",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "type d'indicateur"
            },
            "attribute": "indicator-type",
            "reflect": false,
            "defaultValue": "'underline'"
        },
        "shrinkTabs": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Tabs de taille minimum"
            },
            "attribute": "shrink-tabs",
            "reflect": false,
            "defaultValue": "false"
        }
    }; }
    static get states() { return {
        "tabElements": {}
    }; }
    static get events() { return [{
            "method": "tabChange",
            "name": "tabChange",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Envoie l'index de la tab s\u00E9lectionner"
            },
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            }
        }]; }
    static get elementRef() { return "host"; }
    static get watchers() { return [{
            "propName": "activeTab",
            "methodName": "watchActiveTab"
        }]; }
}
