import { r as registerInstance, c as createEvent, h, g as getElement } from './index-0b18a276.js';
import './component-e22d7bf7.js';
import './ponyfill-f805c928.js';
import { s as supportsCssVariables, M as MDCRipple } from './component-9e8e8eaa.js';

const Step = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.status = 'empty';
        this.active = false;
        this.stepClick = createEvent(this, "stepClick", 7);
        this.previousStep = createEvent(this, "previousStep", 7);
        this.submitStep = createEvent(this, "submitStep", 7);
        this.submitStepper = createEvent(this, "submitStepper", 7);
    }
    componentDidLoad() {
        if (supportsCssVariables(window)) {
            MDCRipple.attachTo(this.header);
        }
        const slot = this.host.shadowRoot.querySelector('slot');
        slot.addEventListener('slotchange', () => {
            this.adjustHeight();
        });
        this.adjustHeight();
    }
    getStepClasses() {
        return {
            'step': true,
            'mdc-typography': true,
            'step-editable': this.editable,
            'step-active': this.active,
            'step-valid': this.status === 'valid',
            'step-empty': this.status === 'empty',
            'step-invalid': this.status === 'invalid',
            'step-last': this.isLast,
        };
    }
    getStepIconContent() {
        if (this.status === 'valid') {
            return h("materials-icon", { name: "done", color: "#fff" });
        }
        else {
            return (this.index + 1).toString();
        }
    }
    getStepIconClasses() {
        return {
            'step-icon': true,
            'step-icon-valid': this.status === 'valid',
            'step-icon-invalid': this.status === 'invalid',
        };
    }
    getStepBodyClasses() {
        return {
            'step-body': true,
            'no-padding': this.noPadding,
            'step-body-active': this.active,
        };
    }
    handleClickNext() {
        if (this.status === 'valid') {
            this.submitStep.emit();
        }
    }
    handleClickFinish() {
        if (this.status === 'valid') {
            this.submitStepper.emit();
        }
    }
    handleClickPrevious() {
        this.previousStep.emit();
    }
    async adjustHeight() {
        if (this.body) {
            this.body.style.maxHeight = this.active ? this.body.scrollHeight + 'px' : '0px';
        }
    }
    handleLast() {
        if (this.isLast) {
            this.host.classList.add('step-last');
        }
        else {
            this.host.classList.remove('step-last');
        }
    }
    render() {
        return (h("div", { class: this.getStepClasses() }, h("div", { ref: el => this.header = el, class: "step-header mdc-ripple-surface", onClick: () => this.stepClick.emit(this.index) }, h("div", { class: this.getStepIconClasses() }, this.getStepIconContent()), h("div", { class: "step-title" }, this.stepTitle, this.summary && h("span", { class: "step-summary" }, h("br", null), this.summary), !this.summary && this.optional && h("span", { class: "step-optional" }, h("br", null), "Optionnel"))), h("div", { ref: el => this.body = el, class: this.getStepBodyClasses() }, h("div", { class: "step-content" }, h("slot", null)), this.showButtons && h("div", { class: "step-buttons" }, this.index > 0 && h("materials-button", { class: "previous-button", onClick: () => this.handleClickPrevious(), color: "#444" }, "Pr\u00E9c\u00E9dent"), this.isLast ?
            h("materials-button", { disabled: this.status !== 'valid' && !this.optional, raised: true, onClick: () => this.handleClickFinish() }, this.confirmationText ? this.confirmationText : 'Valider')
            : h("materials-button", { disabled: this.status !== 'valid' && !this.optional, raised: true, onClick: () => this.handleClickNext() }, "Suivant")), this.confirmationText && !this.showButtons && this.isLast &&
            h("materials-button", { disabled: this.status !== 'valid' && !this.optional, raised: true, onClick: () => this.handleClickFinish() }, this.confirmationText))));
    }
    get host() { return getElement(this); }
    static get watchers() { return {
        "active": ["adjustHeight"],
        "isLast": ["handleLast"]
    }; }
    static get style() { return ":host{\@-webkit-keyframes mdc-ripple-fg-radius-in{from{-webkit-animation-timing-function:cubic-bezier(0.4,0,0.2,1);animation-timing-function:cubic-bezier(0.4,0,0.2,1);-webkit-transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);}to{-webkit-transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));}}\@keyframes mdc-ripple-fg-radius-in{from{-webkit-animation-timing-function:cubic-bezier(0.4,0,0.2,1);animation-timing-function:cubic-bezier(0.4,0,0.2,1);-webkit-transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);transform:translate(var(--mdc-ripple-fg-translate-start,0)) scale(1);}to{-webkit-transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));}}\@-webkit-keyframes mdc-ripple-fg-opacity-in{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:0;}to{opacity:var(--mdc-ripple-fg-opacity,0);}}\@keyframes mdc-ripple-fg-opacity-in{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:0;}to{opacity:var(--mdc-ripple-fg-opacity,0);}}\@-webkit-keyframes mdc-ripple-fg-opacity-out{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:var(--mdc-ripple-fg-opacity,0);}to{opacity:0;}}\@keyframes mdc-ripple-fg-opacity-out{from{-webkit-animation-timing-function:linear;animation-timing-function:linear;opacity:var(--mdc-ripple-fg-opacity,0);}to{opacity:0;}}display:-ms-flexbox;display:flex;-ms-flex-direction:column;flex-direction:column;width:100%;position:relative;}:host .mdc-ripple-surface--test-edge-var-bug{--mdc-ripple-surface-test-edge-var:1px solid #000;visibility:hidden;}:host .mdc-ripple-surface--test-edge-var-bug::before{border:var(--mdc-ripple-surface-test-edge-var);}:host .mdc-ripple-surface{--mdc-ripple-fg-size:0;--mdc-ripple-left:0;--mdc-ripple-top:0;--mdc-ripple-fg-scale:1;--mdc-ripple-fg-translate-end:0;--mdc-ripple-fg-translate-start:0;-webkit-tap-highlight-color:rgba(0,0,0,0);position:relative;outline:none;overflow:hidden;}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{position:absolute;border-radius:50%;opacity:0;pointer-events:none;content:\"\";}:host .mdc-ripple-surface::before{-webkit-transition:opacity 15ms linear,background-color 15ms linear;transition:opacity 15ms linear,background-color 15ms linear;z-index:1;}:host .mdc-ripple-surface.mdc-ripple-upgraded::before{-webkit-transform:scale(var(--mdc-ripple-fg-scale,1));transform:scale(var(--mdc-ripple-fg-scale,1));}:host .mdc-ripple-surface.mdc-ripple-upgraded::after{top:0;left:0;-webkit-transform:scale(0);transform:scale(0);-webkit-transform-origin:center center;transform-origin:center center;}:host .mdc-ripple-surface.mdc-ripple-upgraded--unbounded::after{top:var(--mdc-ripple-top,0);left:var(--mdc-ripple-left,0);}:host .mdc-ripple-surface.mdc-ripple-upgraded--foreground-activation::after{-webkit-animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards;animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards;}:host .mdc-ripple-surface.mdc-ripple-upgraded--foreground-deactivation::after{-webkit-animation:mdc-ripple-fg-opacity-out 150ms;animation:mdc-ripple-fg-opacity-out 150ms;-webkit-transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{background-color:#000;}:host .mdc-ripple-surface:hover::before{opacity:0.04;}:host .mdc-ripple-surface:not(.mdc-ripple-upgraded):focus::before,:host .mdc-ripple-surface.mdc-ripple-upgraded--background-focused::before{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .mdc-ripple-surface:not(.mdc-ripple-upgraded)::after{-webkit-transition:opacity 150ms linear;transition:opacity 150ms linear;}:host .mdc-ripple-surface:not(.mdc-ripple-upgraded):active::after{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .mdc-ripple-surface.mdc-ripple-upgraded{--mdc-ripple-fg-opacity:0.12;}:host .mdc-ripple-surface::before,:host .mdc-ripple-surface::after{top:calc(50% - 100%);left:calc(50% - 100%);width:200%;height:200%;}:host .mdc-ripple-surface.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size,100%);height:var(--mdc-ripple-fg-size,100%);}:host .mdc-ripple-surface[data-mdc-ripple-is-unbounded]{overflow:visible;}:host .mdc-ripple-surface[data-mdc-ripple-is-unbounded]::before,:host .mdc-ripple-surface[data-mdc-ripple-is-unbounded]::after{top:calc(50% - 50%);left:calc(50% - 50%);width:100%;height:100%;}:host .mdc-ripple-surface[data-mdc-ripple-is-unbounded].mdc-ripple-upgraded::before,:host .mdc-ripple-surface[data-mdc-ripple-is-unbounded].mdc-ripple-upgraded::after{top:var(--mdc-ripple-top,calc(50% - 50%));left:var(--mdc-ripple-left,calc(50% - 50%));width:var(--mdc-ripple-fg-size,100%);height:var(--mdc-ripple-fg-size,100%);}:host .mdc-ripple-surface[data-mdc-ripple-is-unbounded].mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size,100%);height:var(--mdc-ripple-fg-size,100%);}:host .mdc-ripple-surface--primary::before,:host .mdc-ripple-surface--primary::after{background-color:#6200ee;}\@supports not (-ms-ime-align:auto){:host .mdc-ripple-surface--primary::before,:host .mdc-ripple-surface--primary::after{background-color:var(--mdc-theme-primary,#6200ee);}}:host .mdc-ripple-surface--primary:hover::before{opacity:0.04;}:host .mdc-ripple-surface--primary:not(.mdc-ripple-upgraded):focus::before,:host .mdc-ripple-surface--primary.mdc-ripple-upgraded--background-focused::before{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .mdc-ripple-surface--primary:not(.mdc-ripple-upgraded)::after{-webkit-transition:opacity 150ms linear;transition:opacity 150ms linear;}:host .mdc-ripple-surface--primary:not(.mdc-ripple-upgraded):active::after{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .mdc-ripple-surface--primary.mdc-ripple-upgraded{--mdc-ripple-fg-opacity:0.12;}:host .mdc-ripple-surface--accent::before,:host .mdc-ripple-surface--accent::after{background-color:#018786;}\@supports not (-ms-ime-align:auto){:host .mdc-ripple-surface--accent::before,:host .mdc-ripple-surface--accent::after{background-color:var(--mdc-theme-secondary,#018786);}}:host .mdc-ripple-surface--accent:hover::before{opacity:0.04;}:host .mdc-ripple-surface--accent:not(.mdc-ripple-upgraded):focus::before,:host .mdc-ripple-surface--accent.mdc-ripple-upgraded--background-focused::before{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .mdc-ripple-surface--accent:not(.mdc-ripple-upgraded)::after{-webkit-transition:opacity 150ms linear;transition:opacity 150ms linear;}:host .mdc-ripple-surface--accent:not(.mdc-ripple-upgraded):active::after{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .mdc-ripple-surface--accent.mdc-ripple-upgraded{--mdc-ripple-fg-opacity:0.12;}:host .mdc-typography{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;}:host .mdc-typography--headline1{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:6rem;line-height:6rem;font-weight:300;letter-spacing:-0.015625em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--headline2{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:3.75rem;line-height:3.75rem;font-weight:300;letter-spacing:-0.0083333333em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--headline3{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:3rem;line-height:3.125rem;font-weight:400;letter-spacing:normal;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--headline4{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:2.125rem;line-height:2.5rem;font-weight:400;letter-spacing:0.0073529412em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--headline5{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:1.5rem;line-height:2rem;font-weight:400;letter-spacing:normal;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--headline6{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:1.25rem;line-height:2rem;font-weight:500;letter-spacing:0.0125em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--subtitle1{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.75rem;font-weight:400;letter-spacing:0.009375em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--subtitle2{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.875rem;line-height:1.375rem;font-weight:500;letter-spacing:0.0071428571em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--body1{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:1rem;line-height:1.5rem;font-weight:400;letter-spacing:0.03125em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--body2{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.875rem;line-height:1.25rem;font-weight:400;letter-spacing:0.0178571429em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--caption{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.75rem;line-height:1.25rem;font-weight:400;letter-spacing:0.0333333333em;text-decoration:inherit;text-transform:inherit;}:host .mdc-typography--button{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.875rem;line-height:2.25rem;font-weight:500;letter-spacing:0.0892857143em;text-decoration:none;text-transform:uppercase;}:host .mdc-typography--overline{font-family:Roboto,sans-serif;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-size:0.75rem;line-height:2rem;font-weight:500;letter-spacing:0.1666666667em;text-decoration:none;text-transform:uppercase;}:host .step-header{--mdc-ripple-fg-size:0;--mdc-ripple-left:0;--mdc-ripple-top:0;--mdc-ripple-fg-scale:1;--mdc-ripple-fg-translate-end:0;--mdc-ripple-fg-translate-start:0;-webkit-tap-highlight-color:rgba(0,0,0,0);display:-ms-flexbox;display:flex;-ms-flex-direction:row;flex-direction:row;height:24px;padding:24px;-ms-flex-align:center;align-items:center;overflow:hidden;cursor:pointer;}:host .step-header::before,:host .step-header::after{position:absolute;border-radius:50%;opacity:0;pointer-events:none;content:\"\";}:host .step-header::before{-webkit-transition:opacity 15ms linear,background-color 15ms linear;transition:opacity 15ms linear,background-color 15ms linear;z-index:1;}:host .step-header.mdc-ripple-upgraded::before{-webkit-transform:scale(var(--mdc-ripple-fg-scale,1));transform:scale(var(--mdc-ripple-fg-scale,1));}:host .step-header.mdc-ripple-upgraded::after{top:0;left:0;-webkit-transform:scale(0);transform:scale(0);-webkit-transform-origin:center center;transform-origin:center center;}:host .step-header.mdc-ripple-upgraded--unbounded::after{top:var(--mdc-ripple-top,0);left:var(--mdc-ripple-left,0);}:host .step-header.mdc-ripple-upgraded--foreground-activation::after{-webkit-animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards;animation:mdc-ripple-fg-radius-in 225ms forwards,mdc-ripple-fg-opacity-in 75ms forwards;}:host .step-header.mdc-ripple-upgraded--foreground-deactivation::after{-webkit-animation:mdc-ripple-fg-opacity-out 150ms;animation:mdc-ripple-fg-opacity-out 150ms;-webkit-transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));transform:translate(var(--mdc-ripple-fg-translate-end,0)) scale(var(--mdc-ripple-fg-scale,1));}:host .step-header::before,:host .step-header::after{top:calc(50% - 100%);left:calc(50% - 100%);width:200%;height:200%;}:host .step-header.mdc-ripple-upgraded::after{width:var(--mdc-ripple-fg-size,100%);height:var(--mdc-ripple-fg-size,100%);}:host .step-header::before,:host .step-header::after{background-color:#000;}:host .step-header:hover::before{opacity:0.04;}:host .step-header:not(.mdc-ripple-upgraded):focus::before,:host .step-header.mdc-ripple-upgraded--background-focused::before{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .step-header:not(.mdc-ripple-upgraded)::after{-webkit-transition:opacity 150ms linear;transition:opacity 150ms linear;}:host .step-header:not(.mdc-ripple-upgraded):active::after{-webkit-transition-duration:75ms;transition-duration:75ms;opacity:0.12;}:host .step-header.mdc-ripple-upgraded{--mdc-ripple-fg-opacity:0.12;}:host .step-header .step-icon{background-color:#ccc;color:#fff;border-radius:50%;width:24px;text-align:center;line-height:24px;}:host .step-header .step-title{margin-left:6px;font-size:14px;font-weight:400;vertical-align:middle;}:host .step-header .step-title .step-summary,:host .step-header .step-title .step-optional{font-weight:400;color:#999;}:host .step-body{position:relative;margin-left:36px;padding:0 24px 0 24px;overflow:hidden;-webkit-transition:max-height 0.5s;transition:max-height 0.5s;}:host .step-body .step-buttons{padding-top:16px;margin-left:-8px;max-height:36px;}:host .step-body.no-padding{padding:0 !important;}:host .step-body.no-padding .step-buttons{padding-left:24px;}:host .previous-button{margin-right:16px;}:host .step-active .step-icon{background-color:var(--mdc-theme-primary,#6200ee);}:host .step-active .step-title{font-weight:600;}:host .step-valid .step-icon{background-color:var(--mdc-theme-primary,#6200ee);}:host .step-invalid .step-icon-invalid{background-color:#ff0000;}:host .step-invalid .step-title{color:#ff0000;}:host .step-empty:not(.step-active) .step-title{color:#ccc;}:host .step-last{padding-bottom:8px;}:host(:not(.step-last))::before{content:\"\";position:absolute;top:56px;bottom:-16px;left:36px;border-left-width:1px;border-left-style:solid;border-left-color:#CCC;}"; }
};

export { Step as materials_step };
